Blocksmurfer
============

.. image:: https://travis-ci.org/1200wd/blocksmurfer.svg?branch=master
    :target: https://travis-ci.org/1200wd/blocksmurfer
    :alt: Travis
.. image:: https://coveralls.io/repos/github/1200wd/blocksmurfer/badge.svg?branch=master
    :target: https://coveralls.io/github/1200wd/blocksmurfer?branch=master    

Install and run a local block explorer.

Bitcoin blockchain explorer based on Python Bitcoinlib (https://github.com/1200wd/bitcoinlib).
Search the blockchain for addresses, transactions, blocks, unspent outputs, etc.

This software currently runs on https://blocksmurfer.io

Data will be retrieved from various service providers such as Blockchair, Blockchain.info or Blockstream.
Blocksmurfer can also receive data from a local bcoin or bitcoind server.

.. image:: https://blocksmurfer.io/static/images/blocksmurfer-localhost-transaction.png
    :alt: Run a bitcoin block explorer locally
